Exception: MailCapture::NotFoundError
- Defined in:
- lib/mailcapture/errors.rb
Overview
Raised when a capture is not found by ID.
Instance Attribute Summary
Attributes inherited from Error
Instance Method Summary collapse
-
#initialize(detail = nil) ⇒ NotFoundError
constructor
A new instance of NotFoundError.
Constructor Details
#initialize(detail = nil) ⇒ NotFoundError
Returns a new instance of NotFoundError.
53 54 55 56 57 58 |
# File 'lib/mailcapture/errors.rb', line 53 def initialize(detail = nil) super( detail || 'Capture not found. It may have expired, been deleted, or the ID is incorrect.', code: 'NOT_FOUND' ) end |